import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// defines the Colors for Pie Chart different sections
const sectionColors = [
  		'black', 'violet', 'green', 'red', 'yellow', 'purple', 'brown', 'grey', 'blue'
		  ];

// link or URL of my dataset which is different countries accidentrate
const csvUrl = 'https://gist.githubusercontent.com/Snigdha6698/4522837ab0626ba3689f5e8ceadaa970/raw/9b84653804528042d4a03afeb42ad385dda52c8e/ICE%25207%2520line%2520dataset.csv';

// Function to get or retrive the data from the URL
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

const svg = select("svg");

const width = + svg.attr('width');
const height = + svg.attr('height');

//text of Format axes
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// These are used to render Pie Chart 
const render = (data, total) => {
  
  const pieData = pie().value(d=>d.users)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
  // used for generating Arcs of the different sections
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);

  
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.users));
  

  
  // Render legend for the data that we had given
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.users));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Years);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>((d.data.users)+'  Users'));
}

// Main function
const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.users = +d.users;
    total += d.users
  });
	render(data,total);
};
run();